summaryrefslogtreecommitdiffstats
path: root/tmk_core/common/avr/suspend.c
diff options
context:
space:
mode:
Diffstat (limited to 'tmk_core/common/avr/suspend.c')
-rw-r--r--tmk_core/common/avr/suspend.c57
1 files changed, 32 insertions, 25 deletions
diff --git a/tmk_core/common/avr/suspend.c b/tmk_core/common/avr/suspend.c
index 28219f4dd..1194a040e 100644
--- a/tmk_core/common/avr/suspend.c
+++ b/tmk_core/common/avr/suspend.c
@@ -102,24 +102,31 @@ static uint8_t wdt_timeout = 0;
*/
static void power_down(uint8_t wdto) {
#ifdef PROTOCOL_LUFA
- if (USB_DeviceState == DEVICE_STATE_Configured) return;
+ if (USB_DeviceState == DEVICE_STATE_Configured) return;
#endif
- wdt_timeout = wdto;
+ wdt_timeout = wdto;
- // Watchdog Interrupt Mode
- wdt_intr_enable(wdto);
+ // Watchdog Interrupt Mode
+ wdt_intr_enable(wdto);
#ifdef BACKLIGHT_ENABLE
- backlight_set(0);
+ backlight_set(0);
#endif
- // Turn off LED indicators
- led_set(0);
+ // Turn off LED indicators
+ uint8_t leds_off = 0;
+#if defined(BACKLIGHT_CAPS_LOCK) && defined(BACKLIGHT_ENABLE)
+ if (is_backlight_enabled()) {
+ // Don't try to turn off Caps Lock indicator as it is backlight and backlight is already off
+ leds_off |= (1<<USB_LED_CAPS_LOCK);
+ }
+#endif
+ led_set(leds_off);
- #ifdef AUDIO_ENABLE
- // This sometimes disables the start-up noise, so it's been disabled
- // stop_all_notes();
- #endif /* AUDIO_ENABLE */
+#ifdef AUDIO_ENABLE
+ // This sometimes disables the start-up noise, so it's been disabled
+ // stop_all_notes();
+#endif /* AUDIO_ENABLE */
#if defined(RGBLIGHT_SLEEP) && defined(RGBLIGHT_ENABLE)
#ifdef RGBLIGHT_ANIMATIONS
rgblight_timer_disable();
@@ -135,20 +142,20 @@ static void power_down(uint8_t wdto) {
#endif
suspend_power_down_kb();
- // TODO: more power saving
- // See PicoPower application note
- // - I/O port input with pullup
- // - prescale clock
- // - BOD disable
- // - Power Reduction Register PRR
- set_sleep_mode(SLEEP_MODE_PWR_DOWN);
- sleep_enable();
- sei();
- sleep_cpu();
- sleep_disable();
-
- // Disable watchdog after sleep
- wdt_disable();
+ // TODO: more power saving
+ // See PicoPower application note
+ // - I/O port input with pullup
+ // - prescale clock
+ // - BOD disable
+ // - Power Reduction Register PRR
+ set_sleep_mode(SLEEP_MODE_PWR_DOWN);
+ sleep_enable();
+ sei();
+ sleep_cpu();
+ sleep_disable();
+
+ // Disable watchdog after sleep
+ wdt_disable();
}
#endif